summaryrefslogtreecommitdiff
path: root/source/script
diff options
context:
space:
mode:
authorJeremy Allison <jra@samba.org>1998-11-11 23:25:51 +0000
committerJeremy Allison <jra@samba.org>1998-11-11 23:25:51 +0000
commit80e0f7e1071f032c5004aecb01a91d1397e6a161 (patch)
treea6b2359feb40c736673d52ea93785f50756f51f4 /source/script
parenta0f9145d6fcf10f30f745601ee1dc7618d4ffb01 (diff)
downloadsamba-80e0f7e1071f032c5004aecb01a91d1397e6a161.tar.gz
rpc_server/srv_netlog.c: Fixed crash bug with ACB_PWNOTREQ.
script/makeyodldocs.sh: Added code to make text docs for non-man page YODL docs. web/cgi.c web/swat.c: SGI compiler warnings fixed. Jeremy.
Diffstat (limited to 'source/script')
-rwxr-xr-xsource/script/makeyodldocs.sh10
1 files changed, 9 insertions, 1 deletions
diff --git a/source/script/makeyodldocs.sh b/source/script/makeyodldocs.sh
index 16a905c6e1a..c943224fe5b 100755
--- a/source/script/makeyodldocs.sh
+++ b/source/script/makeyodldocs.sh
@@ -67,7 +67,7 @@ do
;;
*)
#
# Non man-page YODL docs - just make html.
#
echo $d
rm -f $bn.html
@@ -78,6 +78,14 @@ do
fi
cp $bn.html ../htmldocs || echo "Cannot create $YODLDIR/../htmldocs/$bn.html"
rm -f $bn.html
+ rm -f $bn.txt
+ yodl2txt $d
+ if [ ! -f $bn.txt ]; then
+ echo "Failed to make text page for $d"
+ exit 1
+ fi
+ cp $bn.txt ../textdocs || echo "Cannot create $YODLDIR/../textdocs/$bn.txt"
+ rm -f $bn.txt
;;
esac
done
@@ -67,7 +67,7 @@ do
*)
#
-# Non man-page YODL docs - just make html.
+# Non man-page YODL docs - just make html and text.
#
echo $d